import { defineConfig } from 'vitepress'
import { telegram, gitlab } from './icons'
import { addPlugins } from './theme/plugins/markdown'
import kbd from 'markdown-it-kbd'

export const META_DESCRIPTION = 'Свободная википедия для OS Ximper Linux'

// https://vitepress.dev/reference/site-config
export default defineConfig({
  lang: 'ru-RU',
  srcDir: './docs',
  title: 'Ximper Wiki',
  description: META_DESCRIPTION,
  
  head: [
    ['link', { rel: 'icon', type: 'public', href: '/ximper.ico'}],
    ['link', { rel: 'icon', type: 'public', href: '/ximperlinux.svg' }],
    ['meta', { name: 'theme-color', content: '#62a0ea' }],
    ['meta', { name: 'og:type', content: 'website' }],
    ['meta', { name: 'og:locale', content: 'ru_RU' }],
    ['meta', { name: 'og:site_name', content: 'Ximper Wiki' }]
        ],

  sitemap:
  {
    hostname: 'https://ximper-wiki.ru'
  },

  themeConfig:
  {
    logo: { src: '/ximperlinux.svg', width: 36, height: 36, alt:"Ximper Wiki"},

    // https://vitepress.dev/reference/default-theme-config

    nav:
    [
      { text: 'Главная', link: '/' },
      { text: 'Документация', link: '/wiki' },
      {
        text: 'Меню',
        items:
        [
          { text: 'О проекте', link: '/about' },
          { text: 'Обновления', link: '/updater'}
        ]
      }
    ],

    socialLinks:
    [
      {
        icon:
        {
          svg: telegram
        },
        link: 'https://t.me/ximperlinux'
      },
      { 
        icon:
        {
        svg: gitlab
        },
        link: 'https://gitlab.eterfund.ru/Braumann/XimperWiki'
      }
    ],

    sidebar:
    [
      {
      text: 'Меню:',
      items:
      [
        {
          text: 'Установка OS Ximper Linux', link: '/download-ximper'
        },
      ],
      },
    ],

    editLink:
    {
      pattern: 'https://gitlab.eterfund.ru/Braumann/XimperWiki/tree/master/docs/:path',
      text: 'Предложить изменения на этой странице'
    },

    lastUpdated:
    {
      text: 'Последнее обновление',
      formatOptions:
      {
        dateStyle: 'medium',
        timeStyle: 'medium'
      }
    },

    docFooter:
    {
      prev: 'Предыдущая страница',
      next: 'Следующая страница'
    },

    outlineTitle: 'Оглавление',
    
    footer:
    {
      copyright: 'Copyright © 2023 Ximper Linux Community'
    }
  },
  markdown: {
    config(md) {
      addPlugins(md);
      md.use(kbd);
    }
  }
})